==> evolMap_1.2.33.zip: evolMap/www/tutorial_en.js <==
// tutorial texts to translate
var tutorial_texts = {
  elementsmap: "Element Map",
  beforestarting: 'Before starting to use this page, it is recommended to review this short tutorial to know its information and possibilities.',

  mainpage: 'This is the <span class="highlight">main page</span>.',
  collectionofelements: 'This is a map that represents some elements.',
  eachfigure: 'Each <span class="highlight">circle</span> represents an element.',

  hoveringthemouse: '<span class="highlight">Hovering the mouse</span> over any figure will open a box with basic information.',
  whenclicking: 'And <span class="highlight">clicking</span> on the figure will open its Wikipedia page in the box on the right of the screen.',
  
  timecontrol: 'You can change the time that is displayed using these controls.',

  theuseofthezoom: 'The <span class="highlight">use of zoom</span> will be essential to move freely around the map and discover all the elements distributed throughout the world.',
  zoombuttons: 'In addition to being able to use the mouse or keyboard, with these buttons you can zoom in on the map, zoom out or return to the original zoom.',

  tofindaspecificelement: 'To find a specific element, you can type its name in the <span class="highlight">search engine.</span>',
  todomultiplesearches: 'To do <span class="highlight">multiple searches</span>, you have to write each name on a different line and submit the query by pressing the Shift and Enter keys at the same time.',

  toolsmenu: 'Many aspects of the display can be changed in the tools menu.',
  toolsmenu1: '- The labels that appear along with the elements.',
  toolsmenu2: '- The color of the ring around the images.',
  toolsmenu3: '- The shape of the images according to a category.',
  toolsmenu4: '- The filters of the displayed information.',

  figurescanalsobefiltered: 'You can also <span class="highlight">filter</span> items by selecting one or more of the categories in the legend to see only the types of interest on the map.',

  otherfunctions: 'Other possible functions',
  statisticalgraphs: 'Statistical graphs',
  informativetables: 'Informative tables',

  hello: "Hello!",
  doyouneedhelp: "Do you need help?",
  seethetutorials: "See the tutorials",

  closetutorial: "Close tutorial",
  skiptutorial: "Skip tutorial"
};

==> evolMap_1.3.14.zip: evolMap/www/tutorial_en.js <==
// tutorial texts to translate
var tutorial_texts = {
  elementsmap: "Element Map",
  beforestarting: 'Before starting to use this page, it is recommended to review this short tutorial to know its information and possibilities.',

  mainpage: 'This is the <span class="highlight">main page</span>.',
  collectionofelements: 'This is a map that represents some elements.',
  eachfigure: 'Each <span class="highlight">circle</span> represents an element.',

  hoveringthemouse: '<span class="highlight">Clicking</span> over any figure will open a box with basic information.',
  whenclicking: '<span class="highlight">Clicking</span> on the figure will open an information page in a panel',
  
  timecontrol: 'You can change the time that is displayed using these controls.',

  theuseofthezoom: 'The <span class="highlight">use of zoom</span> will be essential to move freely around the map and discover all the elements distributed throughout the world.',
  zoombuttons: 'In addition to being able to use the mouse or keyboard, with these buttons you can zoom in on the map, zoom out or return to the original zoom.',

  tofindaspecificelement: 'To find a specific element, you can type its name in the <span class="highlight">search engine.</span>',
  todomultiplesearches: 'To do <span class="highlight">multiple searches</span>, you have to write each name on a different line and submit the query by pressing the Shift and Enter keys at the same time.',

  toolsmenu: 'Many aspects of the display can be changed in the tools menu.',
  toolsmenu1: '- The labels that appear along with the elements.',
  toolsmenu2: '- The color of the ring around the images.',
  toolsmenu3: '- The shape of the images according to a category.',
  toolsmenu4: '- The filters of the displayed information.',

  figurescanalsobefiltered: 'You can also <span class="highlight">filter</span> items by selecting one or more of the categories in the legend to see only the types of interest on the map.',
  inthelegend: 'In the <span class="highlight">legend</span> you can change colors and shapes, as well as the attribute to display.',

  otherfunctions: 'Other possible functions',
  statisticalgraphs: 'Statistical graphs',
  informativetables: 'Informative tables',

  inadditiontothispage: 'In addition to this page, there are other pages with different information.',
  tonavigatefromonetoanother: 'To <span class="highlight">navigate from one page to another</span>, return to the main menu clicking the <img src="'+b64Icons.home+'"/> icon available at the top left of the screen.',

  hello: "Hello!",
  doyouneedhelp: "Do you need help?",
  seethetutorials: "See the tutorials",

  closetutorial: "Close tutorial",
  skiptutorial: "Skip tutorial"
};
